This implements the trivial change needed to move back from the hip{Something}_{x, y, z} macros to the natural CUDA syntax of Something.{x, y, z}. This is contained in lines 384-404 in hip_runtime.h. All of the other changes have to do with changing unit tests to use this syntax. The macros are retained for backwards compatibility.

Αυτή η υποβολή περιλαμβάνεται σε:
Alex Voicu
2017-11-19 01:54:12 +00:00
γονέας 85975e719d
υποβολή cffd0e14eb
60 αρχεία άλλαξαν με 270 προσθήκες και 248 διαγραφές
@@ -30,7 +30,7 @@ THE SOFTWARE.
__global__ void Kern(hipLaunchParm lp, float *A)
{
int tx = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
int tx = threadIdx.x + blockIdx.x * blockDim.x;
A[tx] += 1.0f;
}